@@ -1,19 +1,9 @@
 # -*- coding: UTF-8 -*-
-## Copyright 2009-2013 Luc Saffre
-## This file is part of the Lino project.
-## Lino is free software; you can redistribute it and/or modify 
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or
-## (at your option) any later version.
-## Lino is distributed in the hope that it will be useful, 
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
-## GNU General Public License for more details.
-## You should have received a copy of the GNU General Public License
-## along with Lino; if not, see <http://www.gnu.org/licenses/>.
-
 """
+This defines some utilities which require Django settings to be importable.
 
+:copyright: Copyright 2013 by Luc Saffre.
+:license: BSD, see LICENSE for more details.
 """
 
 from __future__ import unicode_literals
@@ -34,6 +24,9 @@ from django.db.models import loading
 #~ from django.utils.formats import get_format
 #~ from django.utils.formats import date_format
 from django.template import defaultfilters
+from django.utils import translation
+
+from djangosite import DJANGO_DEFAULT_LANGUAGE, assert_django_code
 
 from django.core.validators import validate_email, ValidationError, URLValidator
 validate_url = URLValidator()
@@ -197,3 +190,18 @@ def dtomy(d):
     return defaultfilters.date(d,'F Y')
 
 
+def set_language(lang=None):
+    """
+    Thin wrapper around `django.utils.translation`.
+    Activate the given language, or deactivate translations if 
+    the given language is `None` or `'en-us'`.
+    """
+    
+    if lang is None or lang == DJANGO_DEFAULT_LANGUAGE:
+        #~ locale.setlocale(locale.LC_ALL,'')
+        translation.deactivate()
+    else:
+        assert_django_code(lang)
+        translation.activate(lang)
+        
+
