@@ -1,10 +1,17 @@
-## Copyright 2011-2013 Luc Saffre
 """
 Extensions to the `django.test` package:
 :class:`TestCase` for unit tests
-and :class:`DocTest` to be used for testing Sphinx docs.
+and :class:`AutoTestCase`.
+
+:copyright: Copyright 2011-2013 by Luc Saffre.
+:license: BSD, see LICENSE for more details.
 
 """
+import os
+import unittest
+import subprocess
+from setuptools import find_packages
+
 import logging
 logger = logging.getLogger(__name__)
 
@@ -21,62 +28,15 @@ from django.utils.importlib import import_module
 from django.test import TestCase as DjangoTestCase
 from django.db import connection, reset_queries
 
-from django.dispatch import Signal
-testcase_setup = Signal()
-"""
-Emitted each time `djangosite.utils.TestCase.setUp` is called.
-lino.ui.Site uses this signal to reset its SiteConfig cache.
-It is necessary because (afaics) the Django test runner doesn't 
-send a 'connected' signal when it restores the database to a 
-virgin state before running a new test case.
-"""
+from djangosite.utils import testcase_setup
 
+#~ from atelier.test import SubProcessTestCase
+
+#~ class TestCase(DjangoTestCase,SubProcessTestCase):
 class TestCase(DjangoTestCase):
     """
     Adds some extensions to the Django TestCase.
     
-    This is to increase lisibility of your module 
-    when you want to group several separate tests into a 
-    single fixture load. 
-    You gain 4 leading spaces for every line.
-    
-    The Django testrunner creates and initializes a new database 
-    for every TestCase instance.
-    
-    Using `django.test`::
-
-      from django.test import TestCase
-      class DemoTest(TestCase):
-          fixtures = 'std props demo'.split()
-                  
-          def test01(self):
-             ...
-              
-          def test02(self):
-             ...
-         
-    Using `djangosite.utils.test`::
-    
-      from djangosite.utils.test import TestCase
-      class DemoTest(TestCase):
-          fixtures = 'std props demo'.split()
-                  
-      def test01(self):
-         ...
-          
-      def test02(self):
-         ...
-          
-    
-    If you instantiate a `djangosite.utils.test.TestCase` in your test module, 
-    it will automatically inspect the globel namespace of your module and 
-    add all callables whose name begins with "test" to it's test suite.
-    
-    Since all 'testXX' functions are run in a same database, their execution 
-    order may be important: keep in mind that they are executed in 
-    *alphabetical* order, and that database changes remain for the whole 
-    sequence.
-    
     """
     
     longMessage = True # see unittest. used for check_json_result
@@ -101,36 +61,13 @@ class TestCase(DjangoTestCase):
     
     """
     
-    #~ def runTest(self,*args,**kw):
-        #~ # super(TestCase,self).runTest(*args,**kw)
-        #~ m = import_module(self.__module__)
-        #~ for k,v in m.__dict__.items():
-            #~ if k.startswith('test') and callable(v):
-                #~ # print 20110301, k,v
-                #~ # self.__class__.__dict__[k] = v
-                #~ # setattr(self.__class__,k,v)
-                #~ if not getattr(v,'skip',False):
-                    #~ v(self)
                   
     def setUp(self):
         settings.SITE.never_build_site_cache = self.never_build_site_cache
         #~ settings.SITE.remote_user_header = 'REMOTE_USER'
-        super(TestCase,self).setUp()
         testcase_setup.send(self)
+        super(TestCase,self).setUp()
         
-    def test_them_all(self):
-        """
-        This method will be executed automatically since its 
-        name starts with ``test_``.
-        """
-        m = import_module(self.defining_module or self.__module__)
-        #~ for k,v in m.__dict__.items():
-        for k in sorted(m.__dict__.keys()):
-            v = m.__dict__.get(k)
-            if k.startswith('test') and callable(v):
-                if not getattr(v,'skip',False):
-                    v(self)
-                    
                   
     def check_json_result(self,response,expected_keys=None,msg=None):
         """
@@ -244,4 +181,95 @@ class RemoteAuthTestCase(TestCase):
         with self.settings(**mysettings):
             return super(RemoteAuthTestCase,self).__call__(*args,**kw)
     
-        
\ No newline at end of file
+class NoAuthTestCase(TestCase):
+    def __call__(self,*args,**kw):
+        # these tests use remote http authentication, so we override the run() 
+        # method to simulate 
+        #~ settings.SITE.remote_user_header = 'REMOTE_USER'
+        settings.SITE.override_defaults(remote_user_header=None)
+        mysettings = dict()
+        for k in ('MIDDLEWARE_CLASSES',):
+            mysettings[k] = settings.SITE.django_settings.get(k)
+        #~ MIDDLEWARE_CLASSES = settings.SITE.django_settings.get('MIDDLEWARE_CLASSES')
+        with self.settings(**mysettings):
+            return super(NoAuthTestCase,self).__call__(*args,**kw)
+    
+        
+
+class AutoTestCase(TestCase):
+    """
+    Deprecated. No longer recommended. 
+    This brings a very small advantage and some important disadvantages:
+    
+    - more complexity leading to possible problems which are hard to debug
+    - cannot run a function separately.
+    
+    
+    This was to increase lisibility of your module 
+    when you want to group several separate tests into a 
+    single fixture load. 
+    You gain 4 leading spaces for every line.
+    
+    The Django testrunner creates and initializes a new database 
+    for every TestCase instance.
+    
+    Using `django.test`::
+
+      from django.test import TestCase
+      class DemoTest(TestCase):
+          fixtures = 'std props demo'.split()
+                  
+          def test01(self):
+             ...
+              
+          def test02(self):
+             ...
+         
+    Using `djangosite.utils.test`::
+    
+      from djangosite.utils.test import AutoTestCase
+      class DemoTest(AutoTestCase):
+          fixtures = 'std props demo'.split()
+                  
+      def test01(self):
+         ...
+          
+      def test02(self):
+         ...
+          
+    
+    If you instantiate a `djangosite.utils.test.TestCase` in your test module, 
+    it will automatically inspect the globel namespace of your module and 
+    add all callables whose name begins with "test" to it's test suite.
+    
+    Since all 'testXX' functions are run in a same database, their execution 
+    order may be important: keep in mind that they are executed in 
+    *alphabetical* order, and that database changes remain for the whole 
+    sequence.
+    
+    """
+    
+    #~ def runTest(self,*args,**kw):
+        #~ # super(TestCase,self).runTest(*args,**kw)
+        #~ m = import_module(self.__module__)
+        #~ for k,v in m.__dict__.items():
+            #~ if k.startswith('test') and callable(v):
+                #~ # print 20110301, k,v
+                #~ # self.__class__.__dict__[k] = v
+                #~ # setattr(self.__class__,k,v)
+                #~ if not getattr(v,'skip',False):
+                    #~ v(self)
+
+    def test_them_all(self):
+        """
+        This method will be executed automatically since its 
+        name starts with ``test_``.
+        """
+        m = import_module(self.defining_module or self.__module__)
+        #~ for k,v in m.__dict__.items():
+        for k in sorted(m.__dict__.keys()):
+            v = m.__dict__.get(k)
+            if k.startswith('test') and callable(v):
+                if not getattr(v,'skip',False):
+                    v(self)
+                    
